@@ -53,4 +53,10 @@ class DescribeScdnDomainConfigsRequest(RpcRequest):
 		return self.get_query_params().get('SecurityToken')
 
 	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
+		self.add_query_param('SecurityToken',SecurityToken)
+
+	def get_ConfigId(self):
+		return self.get_query_params().get('ConfigId')
+
+	def set_ConfigId(self,ConfigId):
+		self.add_query_param('ConfigId',ConfigId)
\ No newline at end of file
